@@ -6,9 +6,21 @@ use Moose::Util::TypeConstraints;
 with 'MooseX::Clone';
 with Storage (format => 'JSON', io => 'File');
 
+enum 'Graphics::Primitive::Font::AntialiasModes' => (
+    qw(default none gray subpixel)
+);
+enum 'Graphics::Primitive::Font::HintMetrics' => (
+    'default', 'off', 'on'
+);
+enum 'Graphics::Primitive::Font::HintStyles' => (
+    'default', 'none', 'slight', 'medium', 'full'
+);
 enum 'Graphics::Primitive::Font::Slants' => (
     'normal', 'italic', 'oblique'
 );
+enum 'Graphics::Primitive::Font::SubpixelOrders' => (
+    qw(default rgb bgr vrgb vbgr)
+);
 enum 'Graphics::Primitive::Font::Variants' => (
     'normal', 'small-caps'
 );
@@ -16,11 +28,26 @@ enum 'Graphics::Primitive::Font::Weights' => (
     'normal', 'bold'
 );
 
+has 'antialias_mode' => (
+    is => 'rw',
+    isa => 'Graphics::Primitive::Font::AntialiasModes',
+    default => 'default'
+);
 has 'family' => (
     is => 'rw',
     isa => 'Str',
     default => 'Sans'
 );
+has 'hint_metrics' => (
+    is => 'rw',
+    isa => 'Graphics::Primitive::Font::HintMetrics',
+    default => 'default'
+);
+has 'hint_style' => (
+    is => 'rw',
+    isa => 'Graphics::Primitive::Font::HintStyles',
+    default => 'default'
+);
 has 'size' => (
     is => 'rw',
     isa => 'Num',
@@ -31,6 +58,11 @@ has 'slant' => (
     isa => 'Graphics::Primitive::Font::Slants',
     default => 'normal'
 );
+has 'subpixel_order' => (
+    is => 'rw',
+    isa => 'Graphics::Primitive::Font::SubpixelOrders',
+    default => 'default'
+);
 has 'variant' => (
     is => 'rw',
     isa => 'Graphics::Primitive::Font::Variants',
@@ -88,17 +120,64 @@ have an effect if the driver doesn't understand the option.
 
 =over 4
 
-=item I<new>
+=back
+
+=head1 Attributes
+
+=head2 antialias_modes
+
+Set the antialiasing mode for this font. Possible values are default, none,
+gray and subpixel.
+
+=head2 family
+
+Set this font's family.
+
+=head2 hint_metrics
+
+Controls whether to hint font metrics.  Hinting means quantizing them so that
+they are integer values in device space.  This improves the consistency of
+letter and line spacing, however it also means that text will be laid out
+differently at different zoom factors.  May not be supported by all drivers.
+
+=head2 hint_style
+
+Set the the type of hinting to do on font outlines.  Hinting is the process of
+fitting outlines to the pixel grid in order to improve the appearance of the
+result. Since hinting outlines involves distorting them, it also reduces the
+faithfulness to the original outline shapes. Not all of the outline hinting
+styles are supported by all drivers.  Options are default, none, slight,
+medium and full.
+
+=head2 size
+
+Set/Get the size of this font.
+
+=head2 slant
+
+Set/Get the slant of this font.  Valid values are normal, italic and oblique.
+
+=head2 subpixel_order
+
+Set the order of color elements within each pixel on the display device when
+rendering with subpixel antialiasing.  Value values are default, rgb, bgr,
+vrgb and vbgr.
+
+=head2 variant
+
+Set/Get the variant of this font.  Valid values are normal or small-caps.
+
+=head2 weight
+
+Set/Get the weight of this font.  Value valies are normal and bold.
+
+=head1 METHODS
+
+=head2 new
 
 Creates a new Graphics::Primitive::Font.
 
-=back
-
-=head2 Instance Methods
-
-=over 4
-
-=item I<derive>
+=head2 derive
 
 Clone this font but change one or more of it's attributes by passing in a
 hashref of options:
@@ -108,34 +187,10 @@ hashref of options:
 The returned font will be identical to the cloned one, save the attributes
 specified.
 
-=item I<family>
-
-Set this font's family.
-
-=item I<size>
-
-Set/Get the size of this font.
-
-=item I<slant>
-
-Set/Get the slant of this font.  Valid values are normal, italic and oblique.
-
-=item I<variant>
-
-Set/Get the variant of this font.  Valid values are normal or small-caps.
-
-=item I<weight>
-
-Set/Get the weight of this font.  Value valies are normal and bold.
-
-=back
-
 =head1 AUTHOR
 
 Cory Watson, C<< <gphat@cpan.org> >>
 
-Infinity Interactive, L<http://www.iinteractive.com>
-
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-geometry-primitive at rt.cpan.org>, or through
@@ -144,9 +199,7 @@ automatically be notified of progress on your bug as I make changes.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008 by Infinity Interactive, Inc.
-
-L<http://www.iinteractive.com>
+Copyright 2008-2009 by Cory G Watson.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
\ No newline at end of file
