@@ -83,8 +83,6 @@ override('prepare', sub {
 
     return unless defined($self->text) || defined($self->lines) || defined($self->layout);
 
-    return if $self->layout;
-
     unless($self->lines) {
         my $layout = $driver->get_textbox_layout($self);
         $self->layout($layout);
@@ -172,8 +170,6 @@ Vertical alignment.  See L<Graphics::Primitive::Aligned>.
 
 Cory Watson, C<< <gphat@cpan.org> >>
 
-Infinity Interactive, L<http://www.iinteractive.com>
-
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-geometry-primitive at rt.cpan.org>, or through
@@ -182,9 +178,7 @@ automatically be notified of progress on your bug as I make changes.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008 by Infinity Interactive, Inc.
-
-L<http://www.iinteractive.com>
+Copyright 2008-2009 by Cory G Watson.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
\ No newline at end of file
